@@ -29,7 +29,6 @@ from .bloch import (
     display_bloch_sphere,
     display_bloch_sphere_from_bloch_vectors,
     display_bloch_sphere_from_density_matrices,
-    display_bloch_spheres_and_correlations,
 )
 from .confidence_ellipses import plot_confidence_ellipses
 from .controls import (
@@ -38,11 +37,8 @@ from .controls import (
     plot_smooth_controls,
 )
 from .cost_history import plot_cost_history
-from .discriminators import (
-    plot_discriminator,
-    plot_xdata,
-)
 from .filter_functions import plot_filter_functions
+from .histogram import plot_bitstring_probabilities_histogram
 from .populations import plot_populations
 from .style import (
     QCTRL_STYLE_COLORS,
@@ -54,17 +50,15 @@ __all__ = [
     "display_bloch_sphere",
     "display_bloch_sphere_from_bloch_vectors",
     "display_bloch_sphere_from_density_matrices",
-    "display_bloch_spheres_and_correlations",
     "get_qctrl_style",
     "plot_confidence_ellipses",
     "plot_controls",
     "plot_cost_history",
-    "plot_discriminator",
     "plot_filter_functions",
     "plot_populations",
+    "plot_bitstring_probabilities_histogram",
     "plot_sequences",
     "plot_smooth_controls",
-    "plot_xdata",
 ]
 
-__version__ = "3.3.0"
+__version__ = "4.0.0"
