@@ -20,8 +20,8 @@ from typing import (
     Union,
 )
 
+import matplotlib.pyplot as plt
 import numpy as np
-from matplotlib.figure import Figure
 from qctrlcommons.preconditions import check_argument
 
 from .style import (
@@ -31,18 +31,21 @@ from .style import (
 )
 from .utils import (
     create_axes,
+    figure_as_kwarg_only,
     get_units,
 )
 
 
 @qctrl_style()
+@figure_as_kwarg_only
 def plot_confidence_ellipses(
-    figure: Figure,
     ellipse_matrix: np.ndarray,
     estimated_parameters: np.ndarray,
     actual_parameters: Optional[np.ndarray] = None,
     parameter_names: Optional[List[str]] = None,
     parameter_units: Union[str, List[str]] = "Hz",
+    *,
+    figure: plt.Figure,
 ):
     """
     Create an array of confidence ellipse plots.
@@ -52,9 +55,6 @@ def plot_confidence_ellipses(
 
     Parameters
     ----------
-    figure : matplotlib.figure.Figure
-        The matplotlib Figure in which the plots should be placed.
-        Its dimensions will be overridden by this method.
     ellipse_matrix : np.ndarray
         The square matrix which transforms a unit hypersphere in an
         N-dimensional space into a hyperellipse representing the confidence
@@ -73,11 +73,9 @@ def plot_confidence_ellipses(
         The units of each parameter. You can provide a list of strings with
         the units of each parameter, or a single string if all parameters have
         the same units. Defaults to "Hz".
-
-    Raises
-    ------
-    QctrlArgumentsValueError
-        If any of the input parameters are invalid.
+    figure : matplotlib.figure.Figure, optional
+        A matplotlib Figure in which to place the plots.
+        If passed, its dimensions and axes will be overridden.
     """
 
     ellipse_matrix = np.asarray(ellipse_matrix)
