@@ -18,9 +18,11 @@ Functions for plotting control pulses.
 from collections import namedtuple
 from typing import (
     Any,
+    Dict,
     List,
 )
 
+import matplotlib.pyplot as plt
 import numpy as np
 from qctrlcommons.preconditions import check_argument
 
@@ -30,22 +32,27 @@ from .style import (
 )
 from .utils import (
     create_axes,
+    figure_as_kwarg_only,
     get_units,
 )
 
 
 @qctrl_style()
+@figure_as_kwarg_only
 def plot_controls(
-    figure, controls, polar=True, smooth=False, unit_symbol="Hz", two_pi_factor=True
+    controls: Dict,
+    polar: bool = True,
+    smooth: bool = False,
+    unit_symbol: str = "Hz",
+    two_pi_factor: bool = True,
+    *,
+    figure: plt.Figure,
 ):
     """
     Create a plot of the specified controls.
 
     Parameters
     ----------
-    figure : matplotlib.figure.Figure
-        The matplotlib Figure in which the plots should be placed. The dimensions of the Figure
-        will be overridden by this method.
     controls : dict
         The dictionary of controls to plot. The keys should be the names of the controls, and the
         values represent the pulse by either (1) a dictionary with the 'durations' and 'values' for
@@ -83,12 +90,11 @@ def plot_controls(
     two_pi_factor : bool, optional
         Whether the values of the controls should be divided by 2π in the plots.
         Defaults to True.
-
-    Raises
-    ------
-    QctrlArgumentsValueError
-        If any of the input parameters are invalid.
+    figure : matplotlib.figure.Figure, optional
+        A matplotlib Figure in which to place the plots.
+        If passed, its dimensions and axes will be overridden.
     """
+
     boulder_opal_advice = (
         "If you are attempting to plot controls from Boulder Opal, you can obtain"
         " controls in the correct format by using Pwcs as the output nodes."
@@ -161,22 +167,26 @@ def plot_controls(
     if smooth:
         for axes, plot_data in zip(axes_list, plots_data):
             # Convert the list of durations into a list of times at the midpoints of each segment,
-            # with a leading zero and trailing total time.
-            # Length of 'times' is m+2 (m is the number of segments).
+            # with two leading zero and two trailing total times.
+            # Length of 'times' is m+4 (m is the number of segments).
             end_points = np.cumsum(plot_data.xdata)
             times = (
                 np.concatenate(
                     [
-                        [0.0],
+                        [0.0, 0.0],
                         end_points - np.array(plot_data.xdata) * 0.5,
-                        [end_points[-1]],
+                        [end_points[-1], end_points[-1]],
                     ]
                 )
                 / time_scaling
             )
-            # Pad each values array with leading and trailing zeros, to indicate that the pulse is
-            # zero outside the plot domain. Length of 'values_arr' is m+2.
-            values_arr = np.pad(plot_data.values, ((1, 1)), "constant")
+            # Pad each values array (1) with leading and trailing edge values,
+            # to ensure smooth plot, and (2) with leading and trailing zeros,
+            # to indicate that the pulse is zero outside the plot domain.
+            # Length of 'values_arr' is m+4.
+            values_arr = np.pad(
+                np.pad(plot_data.values, ((1, 1)), "edge"), ((1, 1)), "constant"
+            )
 
             axes.plot(times, values_arr, linewidth=2)
             axes.fill(times, values_arr, alpha=0.3)
@@ -219,17 +229,20 @@ def plot_controls(
 
 
 @qctrl_style()
+@figure_as_kwarg_only
 def plot_smooth_controls(
-    figure, controls, polar=True, unit_symbol="Hz", two_pi_factor=True
+    controls: Dict,
+    polar: bool = True,
+    unit_symbol: str = "Hz",
+    two_pi_factor: bool = True,
+    *,
+    figure: plt.Figure,
 ):
     """
     Create a plot of the specified smooth controls.
 
     Parameters
     ----------
-    figure : matplotlib.figure.Figure
-        The matplotlib Figure in which the plots should be placed. The dimensions of the Figure
-        will be overridden by this method.
     controls : dict
         The dictionary of controls to plot. The keys should be the names of the controls, and the
         values represent the pulse by either (1) a dictionary with the 'times' and 'values' for
@@ -266,12 +279,11 @@ def plot_smooth_controls(
     two_pi_factor : bool, optional
         Whether the values of the controls should be divided by 2π in the plots.
         Defaults to True.
-
-    Raises
-    ------
-    ValueError
-        If any of the input parameters are invalid.
+    figure : matplotlib.figure.Figure, optional
+        A matplotlib Figure in which to place the plots.
+        If passed, its dimensions and axes will be overridden.
     """
+
     plots_data: List[Any] = []
     for name, control in controls.items():
         # Process each control depending whether it's passed as a list of samples...
@@ -379,26 +391,49 @@ def _create_plots_data_from_control(
 
 
 @qctrl_style()
-def plot_sequences(figure, seq):
+@figure_as_kwarg_only
+def plot_sequences(sequences: Dict, *, figure: plt.Figure):
     """
     Create plot of dynamical decoupling sequences.
 
     Parameters
     ----------
-    figure: matplotlib.figure.Figure
-        The matplotlib Figure in which the plots should be placed. The dimensions of the Figure
-        will be overridden by this method.
-    seq: dict
-        The dictionary of controls to plot. Works the same as the dictionary for
+    sequences : dict
+        The dictionary of sequences to plot. Works the same as the dictionary for
         plot_controls, but takes 'offset' instead of 'duration' and 'rotation'
         instead of 'value'. Rotations can be around any axis in the XY plane.
         Information about this axis is encoded in the complex argument of the
         rotation. For example, a pi X-rotation is represented by the complex
         number 3.14+0.j, whereas a pi Y-rotation is 0.+3.14j. The argument of the
         complex number is plotted separately as the azimuthal angle.
+        For example, the following ``sequences`` inputs would be valid ::
+
+            sequences={
+              'X': [
+                {'offset': 0.0, 'rotation': 0.1},
+                {'offset': 0.5, 'rotation': 0.3},
+                {'offset': 1.5, 'rotation': 0.2},
+                {'offset': 2.0, 'rotation': 0.4},
+              ],
+              'XY': [
+                {'offset': 0.0, 'rotation': 0.5 + 0.5j},
+                {'offset': 1.0, 'rotation': 0.3},
+                {'offset': 2.0, 'rotation': 0.2 - 0.3j},
+              ],
+            }
+
+    figure : matplotlib.figure.Figure, optional
+        A matplotlib Figure in which to place the plots.
+        If passed, its dimensions and axes will be overridden.
     """
+
+    check_argument(
+        isinstance(sequences, dict) and len(sequences) > 0,
+        "Sequences must be a non-empty dictionary.",
+        {"sequences": sequences},
+    )
     plots_data: List[Any] = []
-    for name, pulses in seq.items():
+    for name, pulses in sequences.items():
         offsets = [pulse["offset"] for pulse in pulses]
         rotations = np.array([pulse["rotation"] for pulse in pulses])
         plots_data = plots_data + _create_plots_data_from_sequence(
@@ -457,9 +492,7 @@ def _create_plots_data_from_sequence(name, offsets, rotations):
     if not np.iscomplexobj(rotations):
         return [
             _PlotSeqData(
-                offsets=offsets,
-                rotations=rotations,
-                label=f"{name}\nrotations\n(rad)",
+                offsets=offsets, rotations=rotations, label=f"{name}\nrotations\n(rad)"
             )
         ]
     return [
