@@ -10,11 +10,13 @@
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
 # License for the specific language.
-
 """
 Functions for plotting filter functions.
 """
 
+from typing import Dict
+
+import matplotlib.pyplot as plt
 import numpy as np
 from qctrlcommons.preconditions import check_argument
 
@@ -23,19 +25,21 @@ from .style import (
     FIG_WIDTH,
     qctrl_style,
 )
+from .utils import figure_as_kwarg_only
 
 
 @qctrl_style()
-def plot_filter_functions(figure, filter_functions):
+@figure_as_kwarg_only
+def plot_filter_functions(
+    filter_functions: Dict,
+    *,
+    figure: plt.Figure,
+):
     """
     Create a plot of the specified filter functions.
 
     Parameters
     ----------
-    figure : matplotlib.figure.Figure
-        The matplotlib Figure in which the plots should be placed. The dimensions of the Figure
-        will be overridden by this method, but may be subsequently modified by the caller if
-        desired.
     filter_functions : dict
         The dictionary of filter functions to plot. The keys should be the names of the filter
         functions, and the values the list of samples representing that filter function. Each such
@@ -53,29 +57,22 @@ def plot_filter_functions(figure, filter_functions):
 
             {
              'Primitive': [
-                 {'frequency': 0.0, 'inverse_power': 15.},
-                 {'frequency': 1.0, 'inverse_power': 12.},
-                 {'frequency': 2.0,
-                  'inverse_power': 3.,
-                  'inverse_power_uncertainty' 0.2},
+                {'frequency': 0.0, 'inverse_power': 15.},
+                {'frequency': 1.0, 'inverse_power': 12.},
+                {'frequency': 2.0, 'inverse_power': 3., 'inverse_power_uncertainty': 0.2},
              ],
              'CORPSE': [
-                 {'frequency': 0.0, 'inverse_power': 10.},
-                 {'frequency': 0.5, 'inverse_power': 8.5},
-                 {'frequency': 1.0,
-                  'inverse_power': 5.,
-                  'inverse_power_uncertainty' 0.1},
-                 {'frequency': 1.5, 'inverse_power': 2.5},
+                {'frequency': 0.0, 'inverse_power': 10.},
+                {'frequency': 0.5, 'inverse_power': 8.5},
+                {'frequency': 1.0, 'inverse_power': 5., 'inverse_power_uncertainty': 0.1},
+                {'frequency': 1.5, 'inverse_power': 2.5},
              ],
             }
-
-    Raises
-    ------
-    QctrlArgumentsValueError
-        If no filter functions are provided.
-    ValueError
-        If any of the inverse power uncertainties are negative.
+    figure : matplotlib.figure.Figure, optional
+        A matplotlib Figure in which to place the plot.
+        If passed, its dimensions and axes will be overridden.
     """
+
     check_argument(
         filter_functions,
         "At least one filter function must be provided.",
@@ -87,8 +84,7 @@ def plot_filter_functions(figure, filter_functions):
 
     axes = figure.subplots(nrows=1, ncols=1)
 
-    for name in filter_functions:
-        samples = filter_functions[name]
+    for name, samples in filter_functions.items():
         frequencies, inverse_powers, inverse_power_uncertainties = np.array(
             list(
                 zip(
@@ -106,8 +102,12 @@ def plot_filter_functions(figure, filter_functions):
             )
         )
 
-        if np.any(inverse_power_uncertainties < 0.0):
-            raise ValueError(f"Uncertainties must all be non-negative: {samples}")
+        check_argument(
+            np.all(inverse_power_uncertainties >= 0.0),
+            "Uncertainties must all be non-negative in filter functions",
+            {"filter_functions": filter_functions},
+            extras={"samples": samples},
+        )
 
         inverse_powers_upper = inverse_powers + inverse_power_uncertainties
         inverse_powers_lower = inverse_powers - inverse_power_uncertainties
