@@ -15,8 +15,18 @@
 Utility functions for plotting.
 """
 
+from functools import wraps
+from inspect import (
+    Parameter,
+    Signature,
+    signature,
+)
+from typing import Optional
+
+import matplotlib.pyplot as plt
 import numpy as np
 from matplotlib.ticker import ScalarFormatter
+from qctrlcommons.preconditions import check_argument
 
 
 def get_units(values):
@@ -61,7 +71,15 @@ def get_units(values):
     return 10**exponent_clipped, prefixes[exponent_clipped]
 
 
-def create_axes(figure, count_x, count_y, width, height, share_x=False, share_y=False):
+def create_axes(
+    figure: plt.Figure,
+    count_x: int,
+    count_y: int,
+    width: float,
+    height: float,
+    share_x: bool = False,
+    share_y: bool = False,
+) -> np.ndarray:
     """
     Create a set of axes with default axis labels and axis formatting.
 
@@ -104,3 +122,47 @@ def create_axes(figure, count_x, count_y, width, height, share_x=False, share_y=
         axes.xaxis.set_major_formatter(ScalarFormatter())
 
     return axes_array
+
+
+def figure_as_kwarg_only(func):
+    """
+    Decorator to mark functions which take a figure as kwarg-only parameter.
+    The decorator:
+        - checks that the first positional argument passed
+            to the decorated function is not a Figure.
+        - if no kwarg figure is passed, create one
+            and pass it to the decorated function.
+        - if a kwarg figure is passed, remove all of its axes.
+    """
+
+    @wraps(func)
+    def new_func(*args, **kwargs):
+        if len(args) > 0:
+            check_argument(  # Remove 2023/01/01
+                not isinstance(args[0], plt.Figure),
+                "The figure parameter is now optional. "
+                "You can omit it or pass it as a keyword parameter.",
+                {func.__code__.co_varnames[0]: args[0]},
+            )
+
+        figure = kwargs.get("figure")
+        if figure is None:
+            # If a figure is not passed, create one.
+            kwargs["figure"] = plt.figure()
+        else:
+            # If a figure is passed, remove all of its axes.
+            for axes in figure.get_axes():
+                axes.remove()
+
+        return func(*args, **kwargs)
+
+    # Update decorated function signature and annotations making the figure parameter optional.
+    sig_params = dict(signature(new_func).parameters)
+    sig_params["figure"] = Parameter(
+        "figure", Parameter.KEYWORD_ONLY, default=None, annotation=Optional[plt.Figure]
+    )
+    # Ignoring type due to https://github.com/python/mypy/issues/12472
+    new_func.__signature__ = Signature(parameters=list(sig_params.values()))  # type: ignore
+    new_func.__annotations__["figure"] = Optional[plt.Figure]
+
+    return new_func
